NetworkSocketAPI

Dependencies:   DnsQuery

Dependents:   HelloWizFi250Interface

Fork of NetworkSocketAPI by NetworkSocketAPI

Revision:
52:52a6c4ea7128
Parent:
46:ac37605ca91d
Child:
53:26b5f1c69822
--- a/NetworkInterface.h	Thu Feb 25 04:11:11 2016 -0600
+++ b/NetworkInterface.h	Thu Feb 25 06:42:40 2016 -0600
@@ -48,11 +48,12 @@
 class NetworkInterface
 {
 public:
     /** Enables DHCP and clears any static address
      *  DHCP resolution does not occur until connect call
      *  DHCP is enabled by default
      */
-    virtual void useDHCP();
+    virtual void setDHCP(bool enable);
 
     /** Set the static IP address of the network interface
      *  @param ip Static IP address, copied internally
@@ -69,6 +70,11 @@
      */
     virtual void setGateway(const char *gateway);
 
+    /** Checks if DHCP is enabled
+     *  @return True if DHCP is enabled
+     */
+    virtual bool getDHCP();
+
     /** Get the IP address
      *  @return IP address of the interface
      */
@@ -119,6 +125,7 @@
     virtual void destroySocket(SocketInterface *socket) = 0;
 
 private:
+    bool _dhcp_enabled;
     char _ip_address[NS_IP_SIZE];
     char _network_mask[NS_IP_SIZE];
     char _gateway[NS_IP_SIZE];
@@ -48,11 +48,12 @@
 {
 public:
-    /** Enables DHCP and clears any static address
-     *  DHCP resolution does not occur until connect call
-     *  DHCP is enabled by default
+    /** Enables or disables DHCP
+     *  @note DHCP resolution does not occur until connect
+     *  @note DHCP is enabled by default
+     *  @param enable Enables DHCP if true
      */